# Generated by Django 3.1.3 on 2020-11-05 15:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vendor', '0007_offer_list_bundle_items'),
    ]

    operations = [
        migrations.AddField(
            model_name='offer',
            name='allow_multiple',
            field=models.BooleanField(default=False, help_text='Confirm the user wants to buy multiples of the product where typically there is just one purchased at a time.', verbose_name='Allow Multiple Purchase'),
        ),
    ]
