# Generated by Django 3.1 on 2020-09-12 01:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vendor', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='address',
            name='name',
            field=models.CharField(blank=True, max_length=80, verbose_name='Address Name'),
        ),
    ]
